/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time.hazelcast;

import eu.ztsh.lib.time.TimeRange;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.time.LocalDate;

import static org.assertj.core.api.Assertions.assertThat;

class TimeRangeSerializerTest {

    private final LocalDate date1 = LocalDate.of(2023, 10, 10);
    private final LocalDate date2 = LocalDate.of(2023, 10, 11);
    private final LocalDate date3 = LocalDate.of(2023, 10, 12);

    private final TimeRangeSerializer serializer = new TimeRangeSerializer();

    @Test
    void identityTest() throws IOException {
        var range1 = new TimeRange(date1, date2);
        var range2 = serializer.read(serializer.write(range1));
        assertThat(range2).isEqualTo(range1);
    }

    @Test
    void nonIdentityTest() throws IOException {
        var range1 = new TimeRange(date1, date2);
        var range2 = new TimeRange(date1, date3);
        var range3 = serializer.read(serializer.write(range1));
        assertThat(range1).isNotEqualTo(range2);
        assertThat(range3).isNotEqualTo(range2);
    }

}
