/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time;

/**
 * Structure for summarized work time.
 *
 * @param summary Short description
 * @param time    String representation of spent hours
 * @param diff    Difference between expected and real work time as {@link Diff} object
 */
public record Calculation(String summary, String time, Diff diff) {

    public static Calculation calculate(String summary, long daysTillToday, long secondsSpent) {
        return new Calculation(summary,
                String.valueOf(((double) secondsSpent) / (60 * 60)),
                Diff.calculate(daysTillToday, secondsSpent));
    }

    public static Calculation off(String summary) {
        return new Calculation(summary, "0.0", Diff.OFF);
    }

}
