/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

public class Timer {

    private LocalDateTime currentSession;
    private final List<Duration> sessions = new ArrayList<>();

    public void start() {
        currentSession = LocalDateTime.now();
    }

    public int stop() {
        var elapsed = new Duration(currentSession, LocalDateTime.now());
        sessions.add(elapsed);
        return elapsed.getTimeSpentSeconds();
    }

    public int getElapsed() {
        return sessions.stream().mapToInt(Duration::getTimeSpentSeconds).sum();
    }

}
