/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time.util;

import eu.ztsh.lib.time.TimeRange;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;

import static eu.ztsh.lib.time.util.TimeUtil.*;

public class TimeRangeUtil {

    public static List<TimeRange> createRanges(Date today) {
        return createRanges(convert(today));
    }

    public static List<TimeRange> createRanges() {
        return createRanges(LocalDate.now());
    }

    public static List<TimeRange> createRanges(LocalDate today) {
        List<TimeRange> ranges = new ArrayList<>();
        FridaySupplier fridaySupplier = isWeekend(today) ? TimeUtil::getLastFriday : TimeUtil::getNextFriday;
        // current range
        ranges.add(new TimeRange(getLastMonday(today), fridaySupplier.supply(today)));
        var limitMonth = today.getMonth().minus(isMonthBeginning(today) ? 2 : 1);
        while (true) {
            today = today.minusWeeks(1);
            var monday = getLastMonday(today);
            var sunday = getNextSunday(today);
            // check if whole week is out of bounds
            if (monday.getMonth().equals(limitMonth) && sunday.getMonth().equals(limitMonth)) {
                break;
            }
            ranges.add(new TimeRange(monday, fridaySupplier.supply(today)));
        }
        Collections.reverse(ranges);
        return ranges;
    }

    public static TimeRange getCurrentWeek() {
        return getWeekFor(LocalDate.now());
    }

    public static TimeRange getLastWeek() {
        return getWeekFor(LocalDate.now().minusWeeks(1));
    }

    private static TimeRange getWeekFor(LocalDate today) {
        FridaySupplier fridaySupplier = isWeekend(today) ? TimeUtil::getLastFriday : TimeUtil::getNextFriday;
        // current range
        return new TimeRange(getLastMonday(today), fridaySupplier.supply(today));
    }

    private interface FridaySupplier {

        LocalDate supply(LocalDate input);

    }

    private TimeRangeUtil() {
        throw new IllegalStateException("Utility class");
    }

}
