/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time;

import org.junit.jupiter.api.Test;

import java.util.concurrent.TimeUnit;

import static org.assertj.core.api.Assertions.assertThat;

class DiffTest {

    private final static long days = 2;
    private final static long secondsSpent = TimeUnit.HOURS.toSeconds(days * 8);

    @Test
    void equalCountTest() {
        commonTest(days, "0:00", State.EQUAL);
    }

    @Test
    void overdueCountTest() {
        commonTest(days + 1, "-8:00", State.OVERDUE);
    }

    @Test
    void advancedCountTest() {
        commonTest(days - 1, "+8:00", State.ADVANCED);
    }

    private static void commonTest(long days, String expectedValue, State expectedState) {
        var diff = Diff.calculate(days, secondsSpent);
        assertThat(diff.value()).isEqualTo(expectedValue);
        assertThat(diff.state()).isEqualTo(expectedState);
    }

}
