/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time;

import org.junit.jupiter.api.Test;

import java.time.LocalDateTime;
import java.time.Month;
import java.util.TreeSet;

import static org.assertj.core.api.Assertions.assertThat;

class DurationTest {

    private final LocalDateTime base = LocalDateTime.of(2023, Month.JULY, 3, 8, 45);
    private final Duration nullDuration = new Duration(base, 0, base);
    private final Duration longDuration = new Duration(base, 3 * 60 * 60, base.plusHours(3));
    private final Duration shortDuration = new Duration(base, 30 * 60, base.plusMinutes(30));

    @Test
    void betweenSimpleComputeTest() {
        var next = base.plusSeconds(100);

        var previousDuration = new Duration(base, 0, base);
        var nextDuration = new Duration(next, 0, next);

        assertThat(Duration.between(previousDuration, nextDuration).getTimeSpentSeconds()).isEqualTo(100);
    }

    @Test
    void betweenInboundComputeTest() {
        assertThat(Duration.between(longDuration, shortDuration)).isEqualByComparingTo(nullDuration);
        assertThat(Duration.between(shortDuration, longDuration)).isEqualByComparingTo(nullDuration);
    }

    @Test
    void sortingTest() {
        var set = new TreeSet<Duration>();
        set.add(nullDuration);
        set.add(shortDuration);
        set.add(longDuration);
        assertThat(set).containsExactly(longDuration, shortDuration, nullDuration);
    }

}
