/******************************************************************************
 * Copyright 2024 ztsh.eu                                                     *
 *                                                                            *
 * Licensed under the Apache License, Version 2.0 (the "License");            *
 * you may not use this file except in compliance with the License.           *
 * You may obtain a copy of the License at                                    *
 *                                                                            *
 *     http://www.apache.org/licenses/LICENSE-2.0                             *
 *                                                                            *
 * Unless required by applicable law or agreed to in writing, software        *
 * distributed under the License is distributed on an "AS IS" BASIS,          *
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.   *
 * See the License for the specific language governing permissions and        *
 * limitations under the License.                                             *
 ******************************************************************************/

package eu.ztsh.lib.time.util;

import org.junit.jupiter.api.Test;

import java.time.LocalDate;

import static eu.ztsh.lib.time.util.TimeUtil.countUntil;
import static org.assertj.core.api.Assertions.assertThat;

class TimeUtilTest {

    @Test
    void secondMondayTest() {
        assertThat(TimeUtil.isMonthBeginning(LocalDate.of(2023, 5, 8))).isFalse();
    }

    @Test
    void firstSundayTest() {
        assertThat(TimeUtil.isMonthBeginning(LocalDate.of(2023, 5, 7))).isTrue();
    }

    @Test
    void firstTuesdayTest() {
        assertThat(TimeUtil.isMonthBeginning(LocalDate.of(2023, 5, 2))).isTrue();
    }

    @Test
    void firstMondayTest() {
        assertThat(TimeUtil.isMonthBeginning(LocalDate.of(2022, 11, 7))).isTrue();
    }

    @Test
    void countTest() {
        var today = LocalDate.of(2023, 7, 23); // Sunday
        var last = TimeUtil.getLastDayOfMonth(today);
        var ranges = TimeRangeUtil.createRanges(last);
        assertThat(ranges).hasSize(6);
        assertThat(countUntil(ranges, today)).isEqualTo(15);
        assertThat(countUntil(ranges, today.plusDays(1))) // Monday
                .isEqualTo(16);
    }

    @Test
    void mondayCalculationTest() {
        var monday = LocalDate.of(2023, 5, 1);
        assertThat(TimeUtil.getLastMonday(monday)).isEqualTo(monday);
        assertThat(TimeUtil.getLastMonday(monday.plusDays(2))).isEqualTo(monday);
    }

}
